PreallocatedContext

Trait PreallocatedContext 

pub unsafe trait PreallocatedContext<'a> { }
Trait marking that a particular context object internally points to memory that must outlive 'a

Safety

This trait is used internally to gate which context markers can safely be used with the preallocated_gen_new function. Do not implement it on your own structures.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors