ThirtyTwoByteHash

Trait ThirtyTwoByteHash 

pub trait ThirtyTwoByteHash {
    // Required method
    fn into_32(self) -> [u8; 32];
}
👎Deprecated since 0.29.0:

Please see v0.29.0 rust-secp256k1/CHANGELOG.md for suggestion

Trait describing something that promises to be a 32-byte uniformly random number.

In particular, anything implementing this trait must have neglibile probability of being zero, overflowing the group order, or equalling any specific value.

Since version 0.29 this has been deprecated; users should instead implement Into<Message> for types that satisfy these properties.

Required Methods

fn into_32(self) -> [u8; 32]

👎Deprecated since 0.29.0:

Please see v0.29.0 rust-secp256k1/CHANGELOG.md for suggestion

Converts the object into a 32-byte array

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors