Tx

Struct Tx 

pub struct Tx {
    pub version: TxVer,
    pub inputs: Confined<Vec<TxIn>, 0, bc::::coding::VarIntArray::{constant#1}>,
    pub outputs: Confined<Vec<TxOut>, 0, bc::::coding::VarIntArray::{constant#1}>,
    pub lock_time: LockTime,
}

Fields

version: TxVerinputs: Confined<Vec<TxIn>, 0, bc::::coding::VarIntArray::{constant#1}>outputs: Confined<Vec<TxOut>, 0, bc::::coding::VarIntArray::{constant#1}>lock_time: LockTime

Implementations

Source

impl Tx

pub fn inputs(&self) -> Iter<'_, TxIn>

pub fn outputs(&self) -> Iter<'_, TxOut>

pub fn is_segwit(&self) -> bool

pub fn to_unsigned_tx(&self) -> Tx

pub fn ntxid(&self) -> [u8; 32]

Computes a “normalized TXID” which does not include any signatures.

This gives a way to identify a transaction that is “the same” as another in the sense of having same inputs and outputs.

pub fn txid(&self) -> Txid

Computes the Txid.

Hashes the transaction excluding the segwit data (i.e. the marker, flag bytes, and the witness fields themselves). For non-segwit transactions which do not have any segwit data, this will be equal to Tx::wtxid().

pub fn wtxid(&self) -> Wtxid

Computes the segwit version of the transaction id.

Hashes the transaction including all segwit data (i.e. the marker, flag bytes, and the witness fields themselves). For non-segwit transactions which do not have any segwit data, this will be equal to [Transaction::txid()].