Xpriv

Struct Xpriv 

pub struct Xpriv { /* private fields */ }

Implementations

Source

impl Xpriv

pub fn new_master(testnet: bool, seed: &[u8]) -> Xpriv

pub fn decode(data: impl Borrow<[u8]>) -> Result<Xpriv, XkeyDecodeError>

pub fn encode(&self) -> [u8; 78]

pub fn is_testnet(&self) -> bool

pub fn depth(&self) -> u8

pub fn child_number(&self) -> DerivationIndex

pub fn parent_fp(&self) -> XpubFp

pub fn fingerprint(self) -> XpubFp

pub fn identifier(self) -> XpubId

pub fn to_xpub(self) -> Xpub

pub fn to_compr_pk(self) -> CompressedPk

pub fn to_xonly_pk(self) -> XOnlyPk

pub fn to_private_ecdsa(self) -> SecretKey

pub fn to_keypair_bip340(self) -> Keypair

pub fn derive_priv<I>(&self, path: impl AsRef<[I]>) -> Xpriv

Attempts to derive an extended private key from a path.

The path argument can be both of type DerivationPath or Vec<ChildNumber>.

pub fn ckd_priv(&self, idx: impl Into<DerivationIndex>) -> Xpriv

Private->Private child key derivation

pub fn chain_code(&self) -> ChainCode